@@ -27,6 +27,7 @@ design <- my_population +
   my_estimator
 
 test_that("reshape works", {
+  set.seed(5)
   dx <- diagnose_design(design, sims = 10, bootstrap_sims = 5)
   reshape_diagnosis(dx)
   expect_error(reshape_diagnosis(dx, select = "mean_estimand"),
@@ -118,7 +119,9 @@ test_that("designs with factors in diagnosands_df do not produce warnings", {
 
 test_that("groups with factors", {
   
-  set.seed(5)
+  skip_on_cran()
+  
+  set.seed(17)
   design <- 
     declare_model(N = 100, u = rnorm(N)) + 
     declare_model(Y_Z_0 = 0, Y_Z_1 = ifelse(rbinom(N, 1, prob = 0.5), 0.1, -0.1) + u) +
@@ -127,18 +130,20 @@ test_that("groups with factors", {
     declare_measurement(Y = reveal_outcomes(Y ~ Z)) +
     declare_estimator(Y ~ Z, inquiry = "ATE_positive")
   
-  diagnosis <- diagnose_design(design, 
-                               make_groups = vars(significant = ifelse(p.value > 0.5, NA, p.value <= 0.05)),
-                               sims = 5
-  )
-  
-  expect_equal(diagnosis$diagnosands_df$significant, c(FALSE, NA))
-  
-  diagnosis <- diagnose_design(design, 
-                               make_groups = vars(significant = factor(ifelse(p.value > 0.5, NA, p.value <= 0.05))),
-                               sims = 5
-  )
-  
-  expect_equal(diagnosis$diagnosands_df$significant, structure(c(1L, NA), .Label = "FALSE", class = "factor"))
+  expect_warning(expect_equal(
+    diagnose_design(design, 
+                    make_groups = vars(significant = ifelse(p.value > 0.5, NA, p.value <= 0.05)),
+                    sims = 5
+    )$diagnosands_df$significant,
+    c(FALSE, NA)
+  ))
+    
+  expect_warning(expect_equal(
+    diagnose_design(design, 
+                    make_groups = vars(significant = factor(ifelse(p.value > 0.5, NA, p.value <= 0.05))),
+                    sims = 5
+    )$diagnosands_df$significant,
+    structure(c(1L, NA), .Label = "FALSE", class = "factor")
+  ))
   
 })
